@@ -3,7 +3,6 @@
 Integration (not unit) tests for pylast.py
 """
 import unittest
-import warnings
 
 import pylast
 
@@ -40,18 +39,6 @@ class TestPyLastAlbum(TestPyLastWithLastFm):
         # Assert
         self.assertTrue(hasattr(track, "album"))
 
-    def test_album_in_artist_tracks(self):
-        # Arrange
-        lastfm_user = self.network.get_user(self.username)
-
-        # Act
-        with warnings.catch_warnings():
-            warnings.filterwarnings("ignore", category=DeprecationWarning)
-            track = lastfm_user.get_artist_tracks(artist="Test Artist")[0]
-
-        # Assert
-        self.assertTrue(hasattr(track, "album"))
-
     def test_album_wiki_content(self):
         # Arrange
         album = pylast.Album("Test Artist", "Test Album", self.network)
