@@ -7,12 +7,10 @@ import sys
 import time
 import unittest
 
+import pylast
 import pytest
 from flaky import flaky
 
-import pylast
-
-
 PY37 = sys.version_info[:2] == (3, 7)
 
 
@@ -21,7 +19,7 @@ def load_secrets():
     if os.path.isfile(secrets_file):
         import yaml  # pip install pyyaml
 
-        with open(secrets_file, "r") as f:  # see example_test_pylast.yaml
+        with open(secrets_file) as f:  # see example_test_pylast.yaml
             doc = yaml.load(f)
     else:
         doc = {}
