@@ -2,11 +2,14 @@
 """
 Integration (not unit) tests for pylast.py
 """
+import calendar
+import datetime as dt
 import os
 import unittest
 import warnings
 
 import pylast
+import pytest
 
 from .test_pylast import TestPyLastWithLastFm
 
@@ -182,20 +185,7 @@ class TestPyLastUser(TestPyLastWithLastFm):
         # Assert
         self.assertEqual(lastfm_user, loaded_user)
 
-    def test_cacheable_user_artist_tracks(self):
-        # Arrange
-        lastfm_user = self.network.get_authenticated_user()
-
-        # Act
-        with warnings.catch_warnings():
-            warnings.filterwarnings("ignore", category=DeprecationWarning)
-            result1 = lastfm_user.get_artist_tracks("Test Artist", cacheable=False)
-            result2 = lastfm_user.get_artist_tracks("Test Artist", cacheable=True)
-            result3 = lastfm_user.get_artist_tracks("Test Artist")
-
-        # Assert
-        self.helper_validate_results(result1, result2, result3)
-
+    @pytest.mark.xfail
     def test_cacheable_user(self):
         # Arrange
         lastfm_user = self.network.get_authenticated_user()
@@ -285,6 +275,10 @@ class TestPyLastUser(TestPyLastWithLastFm):
         # Assert
         self.helper_only_one_thing_in_top_list(albums, pylast.Album)
 
+        top_album = albums[0].item
+        self.assertTrue(len(top_album.info["image"]))
+        self.assertRegex(top_album.info["image"][pylast.SIZE_LARGE], r"^http.+$")
+
     def test_user_tagged_artists(self):
         # Arrange
         lastfm_user = self.network.get_user(self.username)
@@ -360,12 +354,8 @@ class TestPyLastUser(TestPyLastWithLastFm):
     def test_get_recent_tracks_from_to(self):
         # Arrange
         lastfm_user = self.network.get_user("RJ")
-
-        from datetime import datetime
-
-        start = datetime(2011, 7, 21, 15, 10)
-        end = datetime(2011, 7, 21, 15, 15)
-        import calendar
+        start = dt.datetime(2011, 7, 21, 15, 10)
+        end = dt.datetime(2011, 7, 21, 15, 15)
 
         utc_start = calendar.timegm(start.utctimetuple())
         utc_end = calendar.timegm(end.utctimetuple())
@@ -378,6 +368,25 @@ class TestPyLastUser(TestPyLastWithLastFm):
         self.assertEqual(str(tracks[0].track.artist), "Johnny Cash")
         self.assertEqual(str(tracks[0].track.title), "Ring of Fire")
 
+    def test_get_recent_tracks_limit_none(self):
+        # Arrange
+        lastfm_user = self.network.get_user("bbc6music")
+        start = dt.datetime(2020, 2, 15, 15, 00)
+        end = dt.datetime(2020, 2, 15, 15, 40)
+
+        utc_start = calendar.timegm(start.utctimetuple())
+        utc_end = calendar.timegm(end.utctimetuple())
+
+        # Act
+        tracks = lastfm_user.get_recent_tracks(
+            time_from=utc_start, time_to=utc_end, limit=None
+        )
+
+        # Assert
+        self.assertEqual(len(tracks), 11)
+        self.assertEqual(str(tracks[0].track.artist), "Seun Kuti & Egypt 80")
+        self.assertEqual(str(tracks[0].track.title), "Struggles Sounds")
+
     def test_get_playcount(self):
         # Arrange
         user = self.network.get_user("RJ")
@@ -461,6 +470,17 @@ class TestPyLastUser(TestPyLastWithLastFm):
         # Assert
         self.helper_validate_results(result1, result2, result3)
 
+    def test_get_artist_tracks_deprecated(self):
+        # Arrange
+        lastfm_user = self.network.get_user(self.username)
+
+        # Act / Assert
+        with warnings.catch_warnings(), self.assertRaisesRegex(
+            pylast.WSError, "Deprecated - This type of request is no longer supported"
+        ):
+            warnings.filterwarnings("ignore", category=DeprecationWarning)
+            lastfm_user.get_artist_tracks(artist="Test Artist")
+
 
 if __name__ == "__main__":
     unittest.main(failfast=True)
